/* gInfo - Copyright (C) 2004 bakunin - Andrea Marchesini 
 *                                      <bakunin@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef EDITOR_H
#define EDITOR_H

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include <gtksourceview/gtksourceview.h>
#include <gtksourceview/gtksourcelanguage.h>
#include <gtksourceview/gtksourcelanguagesmanager.h>
#include <gtksourceview/gtksourceiter.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/parser.h>
#include <ginfo/ginfo_plugin.h>
#include <confuse.h>

#define NAME "ginfo-editor"
#define AUTHOR "Andrea Marchesini <bakunin@autistici.org>"
#define COPYRIGHT "copyright GPL 2004"

typedef enum
{
  INFO_TEXT,
  INFO_NEWLINE,
  INFO_SPACE,
  INFO_FONT
} parser_font_tag;


typedef struct
{
  PangoStyle style;
  PangoVariant variant;
  PangoWeight weight;
  PangoStretch stretch;
  double scale;
  int size;
  char *foreground;
  char *background;
  GtkJustification justify;
  int underline;
  char *face;

} parser_font;

typedef struct _parser_parser_
{

  char *text;
  parser_font_tag type;

  parser_font font;

  struct _parser_parser_ *next;
} parser_info;

extern GtkSourceBuffer *sourcebuffer;
extern GtkWidget *editorwin;
extern int editor_change;
extern GtkWidget *editor_undo_item;
extern GtkWidget *editor_redo_item;
extern GtkWidget *editor_save_item;
extern GtkWidget *editor_save_button;
extern GtkWidget *highlight_normal;
extern GtkWidget *highlight_xml;
extern char *editor_output;


/* main.c */
void usage (int);
void fatal (char *, ...);

/* graphic.c */
int graphic_create_window (void);
void graphic_quit (GtkWidget *, gpointer);

/* editor.c */
int editor_notebook (GtkWidget *);
int editor_dialog_ask_save (void);
void editor_new (GtkWidget *, gpointer);
void editor_open_file(char *);
void editor_open (GtkWidget *, gpointer);
void editor_save (GtkWidget *, gpointer);
void editor_save_as_m (GtkWidget *, gpointer);
void editor_select_all (GtkWidget *, gpointer);
void editor_undo (GtkWidget *, gpointer);
void editor_redo (GtkWidget *, gpointer);
void editor_cut (GtkWidget *, gpointer);
void editor_copy (GtkWidget *, gpointer);
void editor_paste (GtkWidget *, gpointer);
void editor_delete (GtkWidget *, gpointer);
void editor_find (GtkWidget *, gpointer);
void editor_set_lang (GtkWidget *, gpointer);
void editor_dialog (char *, ...);
void editor_set_preferences(int, int, int, int, int);

/* viewer.c */
int viewer_notebook (GtkWidget *);
void viewer_create_tree (ginfo_docs *, int);

/* parser.c */
int parser_notebook (GtkWidget *);

/* tips.c */
int tips_notebook (GtkWidget *);
void tips_create_list (ginfo_tips *, int);

/* preferences.c */
void preferences_create (void);
void preferences_open(void);

/* tools */
void tools_wordcount(GtkWidget *, gpointer);
void tools_tagslist(GtkWidget *, gpointer);

#endif

/* EOF */
